@@ -1,10 +1,10 @@
-# $Id: SQLite.pm 69 2019-01-04 00:24:35Z stro $
+# $Id: SQLite.pm 70 2019-01-04 19:39:59Z stro $
 
 package CPAN::SQLite;
 use strict;
 use warnings;
 
-our $VERSION = '0.213';
+our $VERSION = '0.214';
 
 use English qw/-no_match_vars/;
 
@@ -98,7 +98,7 @@ CPAN::SQLite - maintain and search a minimal CPAN database
 
 =head1 VERSION
 
-version 0.213
+version 0.214
 
 =head1 SYNOPSIS
 
@@ -112,9 +112,8 @@ version 0.213
 
 This package is used for setting up, maintaining, and
 searching a CPAN database consisting of the information
-stored in the three main CPAN indices:
-F<$CPAN/modules/03modlist.data.gz>,
-F<$CPAN/modules/02packages.details.txt.gz>, and
+stored in the two main CPAN indices:
+F<$CPAN/modules/02packages.details.txt.gz> and
 F<$CPAN/authors/01mailrc.txt.gz>. It should be
 considered at an alpha stage of development.
 
